@@ -4,11 +4,15 @@
 condiNumber <- function(x, ...)
     UseMethod("condiNumber")
 
-condiNumber.default <- function(x, exact=FALSE, norm=FALSE, print.level=1, ...) {
+condiNumber.default <- function(x, exact=FALSE, norm=FALSE,
+                                printLevel=print.level, print.level=1, 
+   digits = getOption( "digits" ), ... ) {
    ## x:  a matrix, condition number of which are to be printed
    ## exact: whether the condition number have to be exact or approximated (see 'kappa')
    ## norm: whether to normalise the matrix' columns.
-   ## print.level: whether to print the condition numbers while calculating.  Useful for interactive testing. 
+   ## printLevel: whether to print the condition numbers while calculating.  Useful for interactive testing. 
+   savedDigits <- getOption("digits")
+   options( digits = digits )
    if(dim(x)[2] > dim(x)[1]) {
       warning(paste(dim(x)[1], "rows and", dim(x)[2], "columns, use transposed matrix"))
       x <- t(x)
@@ -21,12 +25,14 @@ condiNumber.default <- function(x, exact=FALSE, norm=FALSE, print.level=1, ...)
     for(i in seq(length=ncol(x))) {
         m <- x[,1:i]
         cn[i] <- kappa(m, exact=exact)
-        if(print.level > 0)
+        if(printLevel > 0)
             cat(colnames(x)[i], "\t", cn[i], "\n")
     }
    names(cn) <- colnames(x)
+   options( digits = savedDigits )
    invisible(cn)
 }
 
 condiNumber.maxLik <- function(x, ...)
-    condiNumber.default(hessian(x, ...)[activePar(x), activePar(x),drop=FALSE])
+    condiNumber.default( x = hessian(x)[activePar(x), activePar(x),drop=FALSE],
+       ... )
